#################################
A tool to process MD trajectories
#################################

.. |master_build| image:: https://travis-ci.com/sizmailov/pyxmolpp2.svg?branch=master
    :alt: master status
    :target: https://travis-ci.com/sizmailov/pyxmolpp2


.. |master_coverage| image:: https://codecov.io/gh/sizmailov/pyxmolpp2/branch/master/graph/badge.svg
    :alt: master coverage
    :target: https://codecov.io/gh/sizmailov/pyxmolpp2/branch/master


.. |dev_build| image:: https://travis-ci.com/sizmailov/pyxmolpp2.svg?branch=dev
    :alt: dev status
    :target: https://travis-ci.com/sizmailov/pyxmolpp2


.. |dev_coverage| image:: https://codecov.io/gh/sizmailov/pyxmolpp2/branch/dev/graph/badge.svg
    :alt: dev coverage
    :target: https://codecov.io/gh/sizmailov/pyxmolpp2/branch/dev

.. image:: https://badge.fury.io/py/pyxmolpp2.svg
    :target: https://badge.fury.io/py/pyxmolpp2

================= =================
    **master**         **dev**
================= =================
|master_build|    |dev_build|
|master_coverage| |dev_coverage|
================= =================

-----
About
-----

C++ and python library to process MD trajectories.

-------
Install
-------

.. code-block:: bash

    # from pypi
    python -m pip install pyxmolpp2

    # from github dev branch
    python -m pip install git+https://github.com/sizmailov/pyxmolpp2.git@dev

See `install page <https://sizmailov.github.io/pyxmolpp2/api/python/install.html>`_ for more details

-------------
Documentation
-------------

https://sizmailov.github.io/pyxmolpp2/

The documentation includes usage examples and python API reference.

------------
Contribution
------------

Issues and PRs are welcome

-------
License
-------

Software is distributed under MIT license.